Welcome to mriqc’s documentation! — mriqc 0.1.0 documentation

# Welcome to mriqc’s documentation!

# mriqc

The mriqc package provides a series of NR, IQMs to used in QAPs for MRI.

## Dependencies

Make sure you have FSL and AFNI installed, and the binaries available in the system’s $PATH.

## Installation

Just issue:

    pip install mriqc

## Example command line:

    mriqc -i ~/Data/bids_dataset -o out/ -w work/

Contents:

# Indices and tables

- Index
- Module Index
- Search Page